 # Geosoup 0.1.0

 Geospatial data manipulation using GDAL in python

This library is a minimalistic software distribution for manipulation of geospatial data objects. All the heavy lifting is done by GDAL, numpy and, scipy. 

Install using:

`pip install geosoup`


